import { createRouter, createWebHistory } from 'vue-router'
import Login from '../views/Login/Login.vue'
import Home from '../views/Home/Home.vue'
import Layout from '../views/Layout/index.vue'
import NotFound from '../views/Error/404.vue'
import Forbidden from '../views/Error/403.vue'

import dynamicRouter from "./dynamic-router";

let allRouter: Array<any> = [];

function checkPermission(item: any, temp?: string) {
  let _temp: string = temp||''
  for (let i = 0; i < item.length; i++) {
    if (item[i].children) {
      checkPermission(item[i].children, _temp ? _temp + '/' + item[i].path : item[i].path)
    } else {
      if (temp) {
        temp = _temp + '/' + item[i].path
      } else {
        temp = item[i].path
      }
      allRouter.push(temp)
    }
  }
}
checkPermission(dynamicRouter)

//初始化路由
const routes = [
  {
    //登录
    path: '/login',
    name: 'Login',
    component: Login
  }
]

//动态路由
export const DynamicRoutes = [
  {
    path: '',
    component: Layout,
    name: 'container',
    redirect: 'home',
    meta: {
      requiresAuth: true,
      name: '首页'
    },
    children: [
      {
        path: '/',
        component: Home,
        name: 'Home',
        meta: {
          name: '首页',
          icon: 'HomeFilled',
          side_show: true
        }
      }
    ]
  },
  {
    path: '/403',
    component: Forbidden
  },
  {
    path: "/:catchAll(.*)",
    component: NotFound,
    beforeEnter: (to, from, next) => {
      // console.log(233, allRouter, to)
      if (allRouter.includes(to.path)) {
        next('/403');
      } else {
        next(); // 如果路由匹配到了已定义的路径，正常进入
      }
    }
  }
]




const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes
})


// const router = createRouter({
//   history: createWebHistory(import.meta.env.BASE_URL),
//   routes: [
//     {
//       path: '/',
//       name: 'home',
//       component: Home
//     },
//     {
//       path: '/login',
//       name: 'login',
//       component: () => import('../views/Login/Login.vue')
//     },
//     {
//       path: '/user',
//       name: 'User',
//       component: () => import('../views/User/User.vue')
//     },
//     {
//       path: '/data-stat',
//       name: 'DataStat',
//       component: () => import('../views/DataStat/DataStat.vue')
//     },
//     {
//       path: '/user/review-info',
//       name: 'UserReviewInfo',
//       component: () => import('../views/User/UserReviewInfo.vue')
//     },
//     {
//       path: '/user/review-record',
//       name: 'ReviewRecord',
//       component: () => import('../views/User/ReviewRecord.vue')
//     },
//     {
//       path: '/user/review-record/info',
//       name: 'ReviewRecordInfo',
//       component: () => import('../views/User/ReviewRecordInfo.vue')
//     },
//     {
//       path: '/user/driver-action',
//       name: 'DriverAction',
//       component: () => import('../views/User/DriverAction.vue')
//     },
//     {
//       path: '/account/voice-call',
//       name: 'VoiceCall',
//       component: () => import('../views/Account/VoiceCall.vue')
//     },
//     {
//       path: '/account/voice-call/info',
//       name: 'VoiceCallInfo',
//       component: () => import('../views/Account/VoiceCallInfo.vue')
//     },
//     {
//       path: '/account/delayed',
//       name: 'Delayed',
//       component: () => import('../views/Account/Delayed.vue')
//     },
//     {
//       path: '/account/attestation',
//       name: 'Attestation',
//       component: () => import('../views/Account/Attestation.vue')
//     },
//     {
//       path: '/account/attestation/info',
//       name: 'AttestationInfo',
//       component: () => import('../views/Account/AttestationInfo.vue')
//     },
//     {
//       path: '/account/meicoin',
//       name: 'Meicoin',
//       component: () => import('../views/Account/Meicoin.vue')
//     },
//     {
//       path: '/account/yun-trading',
//       name: 'YunTrading',
//       component: () => import('../views/Account/YunTrading.vue')
//     },
//     {
//       path: '/oplog',
//       name: 'Oplog',
//       component: () => import('../views/Oplog/Oplog.vue')
//     },
//     {
//       path: '/v-call',
//       name: 'VCall',
//       component: () => import('../views/VCall/VCall.vue')
//     },
//     {
//       path: '/v-call/info',
//       name: 'VCallInfo',
//       component: () => import('../views/VCall/VCallInfo.vue')
//     },
//     {
//       path: '/complain',
//       name: 'Complain',
//       component: () => import('../views/Complain/Complain.vue')
//     },
//     {
//       path: '/maintenance/shidian',
//       name: 'ShiDian',
//       component: () => import('../views/ShiDian/ShiDian.vue')
//     },
//     {
//       path: '/maintenance/shidian/add',
//       name: 'AddItem',
//       component: () => import('../views/ShiDian/AddItem.vue')
//     },
//     {
//       path: '/maintenance/shidian/edit',
//       name: 'EditItem',
//       component: () => import('../views/ShiDian/EditItem.vue')
//     },
//     {
//       path: '/main/post/list',
//       name: 'PostList',
//       component: () => import('../views/Main/PostList.vue')
//     },
//     {
//       path: '/main/post/info',
//       name: 'PostInfo',
//       component: () => import('../views/Main/PostInfo.vue')
//     },
//     {
//       path: '/transport/reviewlist',
//       name: 'ReviewList',
//       component: () => import('../views/Transport/ReviewList.vue')
//     },
//     {
//       path: '/transport/liberal',
//       name: 'Liberal',
//       component: () => import('../views/Transport/Liberal.vue')
//     },
//   ]
// })


// router.beforeEach((to,from,next)=>{
//   console.log(to)
// })

export default router
